@@ -101,6 +101,10 @@ static ServerMediaSession* createNewSMS(UsageEnvironment& env,
     // Assumed to be an AMR Audio file:
     NEW_SMS("AMR Audio");
     sms->addSubsession(AMRAudioFileServerMediaSubsession::createNew(env, fileName, reuseSource));
+  } else if (strcmp(extension, ".ac3") == 0) {
+    // Assumed to be an AC-3 Audio file:
+    NEW_SMS("AC-3 Audio");
+    sms->addSubsession(AC3AudioFileServerMediaSubsession::createNew(env, fileName, reuseSource));
   } else if (strcmp(extension, ".m4e") == 0) {
     // Assumed to be a MPEG-4 Video Elementary Stream file:
     NEW_SMS("MPEG-4 Video");
